timeseries.test\_mollifier.TestMollifier.test\_refinement\_counts
=================================================================

.. currentmodule:: timeseries.test_mollifier

.. automethod:: TestMollifier.test_refinement_counts